summaryrefslogtreecommitdiffstats
path: root/parts/filter
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filter')
-rw-r--r--parts/filter/filterpart.cpp10
-rw-r--r--parts/filter/filterpart.h2
-rw-r--r--parts/filter/kdevfilterIface.cpp2
-rw-r--r--parts/filter/kdevfilterIface.h4
-rw-r--r--parts/filter/shellfilterdlg.cpp42
-rw-r--r--parts/filter/shellfilterdlg.h14
-rw-r--r--parts/filter/shellinsertdlg.cpp44
-rw-r--r--parts/filter/shellinsertdlg.h14
8 files changed, 66 insertions, 66 deletions
diff --git a/parts/filter/filterpart.cpp b/parts/filter/filterpart.cpp
index 8804e701..dbb0dfc6 100644
--- a/parts/filter/filterpart.cpp
+++ b/parts/filter/filterpart.cpp
@@ -29,7 +29,7 @@
static const KDevPluginInfo data("kdevfilter");
K_EXPORT_COMPONENT_FACTORY( libkdevfilter, FilterFactory( data ) )
-FilterPart::FilterPart(QObject *parent, const char *name, const QStringList &)
+FilterPart::FilterPart(TQObject *parent, const char *name, const TQStringList &)
: KDevPlugin(&data, parent, name ? name : "FilterPart")
{
setInstance(FilterFactory::instance());
@@ -38,13 +38,13 @@ FilterPart::FilterPart(QObject *parent, const char *name, const QStringList &)
KAction *action;
action = new KAction( i18n("Execute Command..."), 0,
- this, SLOT(slotShellInsert()),
+ this, TQT_SLOT(slotShellInsert()),
actionCollection(), "tools_insertshell" );
action->setToolTip(i18n("Execute shell command"));
action->setWhatsThis(i18n("<b>Execute shell command</b><p>Executes a shell command and outputs its result into the current document."));
action = new KAction( i18n("Filter Selection Through Command..."), 0,
- this, SLOT(slotShellFilter()),
+ this, TQT_SLOT(slotShellFilter()),
actionCollection(), "tools_filtershell" );
action->setToolTip(i18n("Filter selection through a shell command"));
action->setWhatsThis(i18n("<b>Filter selection through shell command</b><p>Filters selection through a shell command and outputs its result into the current document."));
@@ -70,7 +70,7 @@ void FilterPart::slotShellInsert()
KParts::ReadWritePart *part
= dynamic_cast<KParts::ReadWritePart*>(partController()->activePart());
- QWidget *view = partController()->activeWidget();
+ TQWidget *view = partController()->activeWidget();
if (!part || !view) {
kdDebug(9029) << "no rw part" << endl;
return;
@@ -109,7 +109,7 @@ void FilterPart::slotShellFilter()
KParts::ReadWritePart *part
= dynamic_cast<KParts::ReadWritePart*>(partController()->activePart());
- QWidget *view = partController()->activeWidget();
+ TQWidget *view = partController()->activeWidget();
if (!part || !view) {
kdDebug(9029) << "no rw part" << endl;
return;
diff --git a/parts/filter/filterpart.h b/parts/filter/filterpart.h
index ec731f12..55b89dbc 100644
--- a/parts/filter/filterpart.h
+++ b/parts/filter/filterpart.h
@@ -24,7 +24,7 @@ class FilterPart : public KDevPlugin
Q_OBJECT
public:
- FilterPart( QObject *parent, const char *name, const QStringList & );
+ FilterPart( TQObject *parent, const char *name, const TQStringList & );
~FilterPart();
public slots:
diff --git a/parts/filter/kdevfilterIface.cpp b/parts/filter/kdevfilterIface.cpp
index 55a0421a..3df749a4 100644
--- a/parts/filter/kdevfilterIface.cpp
+++ b/parts/filter/kdevfilterIface.cpp
@@ -14,7 +14,7 @@
#include "filterpart.h"
KDevFilterIface::KDevFilterIface( FilterPart* part )
- : QObject( part ), DCOPObject( "KDevFilter" ), m_part( part )
+ : TQObject( part ), DCOPObject( "KDevFilter" ), m_part( part )
{
}
diff --git a/parts/filter/kdevfilterIface.h b/parts/filter/kdevfilterIface.h
index 46a14277..d51acdbc 100644
--- a/parts/filter/kdevfilterIface.h
+++ b/parts/filter/kdevfilterIface.h
@@ -2,12 +2,12 @@
#ifndef KDEVFILTERIFACE_H
#define KDEVFILTERIFACE_H
-#include <qobject.h>
+#include <tqobject.h>
#include <dcopobject.h>
class FilterPart;
-class KDevFilterIface : public QObject, public DCOPObject
+class KDevFilterIface : public TQObject, public DCOPObject
{
Q_OBJECT
K_DCOP
diff --git a/parts/filter/shellfilterdlg.h b/parts/filter/shellfilterdlg.h
index 3307c060..6642eb92 100644
--- a/parts/filter/shellfilterdlg.h
+++ b/parts/filter/shellfilterdlg.h
@@ -12,7 +12,7 @@
#ifndef _SHELLFILTERDLG_H_
#define _SHELLFILTERDLG_H_
-#include <qdialog.h>
+#include <tqdialog.h>
class QComboBox;
class QPushButton;
@@ -30,9 +30,9 @@ public:
virtual int exec();
- void setText(const QString &str)
+ void setText(const TQString &str)
{ m_instr = str.local8Bit(); }
- QString text() const
+ TQString text() const
{ return m_outstr; }
private slots:
@@ -42,11 +42,11 @@ private slots:
void slotProcessExited(KProcess *);
private:
- QPushButton *start_button, *cancel_button;
- QComboBox *combo;
+ TQPushButton *start_button, *cancel_button;
+ TQComboBox *combo;
KProcess *m_proc;
- QCString m_instr;
- QString m_outstr;
+ TQCString m_instr;
+ TQString m_outstr;
};
#endif
diff --git a/parts/filter/shellinsertdlg.h b/parts/filter/shellinsertdlg.h
index c6f0696b..cb0992c9 100644
--- a/parts/filter/shellinsertdlg.h
+++ b/parts/filter/shellinsertdlg.h
@@ -12,7 +12,7 @@
#ifndef _SHELLINSERTDLG_H_
#define _SHELLINSERTDLG_H_
-#include <qdialog.h>
+#include <tqdialog.h>
class QComboBox;
class QPushButton;
@@ -30,20 +30,20 @@ public:
virtual int exec();
- QString text() const
- { return QString::fromLocal8Bit(m_str); }
+ TQString text() const
+ { return TQString::fromLocal8Bit(m_str); }
private slots:
void slotStartClicked();
void slotReceivedStdout(KProcess *, char *text, int len);
void slotProcessExited(KProcess *);
- void executeTextChanged( const QString &text);
+ void executeTextChanged( const TQString &text);
private:
- QPushButton *start_button, *cancel_button;
- QComboBox *combo;
+ TQPushButton *start_button, *cancel_button;
+ TQComboBox *combo;
KProcess *m_proc;
- QCString m_str;
+ TQCString m_str;
};
#endif
diff --git a/parts/filter/shellfilterdlg.cpp b/parts/filter/shellfilterdlg.cpp
index 7e967cda..484cb4cc 100644
--- a/parts/filter/shellfilterdlg.cpp
+++ b/parts/filter/shellfilterdlg.cpp
@@ -11,9 +11,9 @@
#include "shellfilterdlg.h"
-#include <qcombobox.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
+#include <tqcombobox.h>
+#include <tqlayout.h>
+#include <tqpushbutton.h>
#include <kbuttonbox.h>
#include <kconfig.h>
#include <kdebug.h>
@@ -29,11 +29,11 @@
ShellFilterDialog::ShellFilterDialog()
- : QDialog(0, "shell filter dialog", true)
+ : TQDialog(0, "shell filter dialog", true)
{
- QVBoxLayout *layout = new QVBoxLayout(this, 10, 4);
+ TQVBoxLayout *layout = new TQVBoxLayout(this, 10, 4);
- combo = new QComboBox(true, this);
+ combo = new TQComboBox(true, this);
combo->setDuplicatesEnabled(false);
layout->addWidget(combo);
@@ -44,10 +44,10 @@ ShellFilterDialog::ShellFilterDialog()
buttonbox->layout();
layout->addWidget(buttonbox);
- connect( start_button, SIGNAL(clicked()),
- this, SLOT(slotStartClicked()) );
- connect( cancel_button, SIGNAL(clicked()),
- this, SLOT(reject()) );
+ connect( start_button, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(slotStartClicked()) );
+ connect( cancel_button, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(reject()) );
m_proc = 0;
@@ -62,8 +62,8 @@ ShellFilterDialog::~ShellFilterDialog()
kdDebug(9029) << "~ShellFilterDialog" << endl;
delete m_proc;
- // QComboBox API is a bit incomplete :-(
- QStringList list;
+ // TQComboBox API is a bit incomplete :-(
+ TQStringList list;
for (int i=0; i < combo->count(); ++i)
list << combo->text(i);
@@ -76,17 +76,17 @@ ShellFilterDialog::~ShellFilterDialog()
void ShellFilterDialog::slotStartClicked()
{
start_button->setEnabled(false);
- m_outstr = QCString();
+ m_outstr = TQCString();
delete m_proc;
m_proc = new KShellProcess("/bin/sh");
(*m_proc) << combo->currentText();
- connect( m_proc, SIGNAL(receivedStdout(KProcess*, char *, int)),
- this, SLOT(slotReceivedStdout(KProcess*, char *, int)) );
- connect( m_proc, SIGNAL(wroteStdin(KProcess*)),
- this, SLOT(slotWroteStdin(KProcess*)) );
- connect( m_proc, SIGNAL(processExited(KProcess*)),
- this, SLOT(slotProcessExited(KProcess*)) );
+ connect( m_proc, TQT_SIGNAL(receivedStdout(KProcess*, char *, int)),
+ this, TQT_SLOT(slotReceivedStdout(KProcess*, char *, int)) );
+ connect( m_proc, TQT_SIGNAL(wroteStdin(KProcess*)),
+ this, TQT_SLOT(slotWroteStdin(KProcess*)) );
+ connect( m_proc, TQT_SIGNAL(processExited(KProcess*)),
+ this, TQT_SLOT(slotProcessExited(KProcess*)) );
m_proc->start(KProcess::NotifyOnExit, KProcess::All);
m_proc->writeStdin(m_instr, m_instr.length());
}
@@ -95,13 +95,13 @@ void ShellFilterDialog::slotStartClicked()
int ShellFilterDialog::exec()
{
start_button->setEnabled(true);
- return QDialog::exec();
+ return TQDialog::exec();
}
void ShellFilterDialog::slotReceivedStdout(KProcess *, char *text, int len)
{
- m_outstr += QString::fromLocal8Bit(text, len+1);
+ m_outstr += TQString::fromLocal8Bit(text, len+1);
kdDebug(9029) << "outstr " << m_outstr << endl;
}
diff --git a/parts/filter/shellinsertdlg.cpp b/parts/filter/shellinsertdlg.cpp
index a1474ed2..e36278b5 100644
--- a/parts/filter/shellinsertdlg.cpp
+++ b/parts/filter/shellinsertdlg.cpp
@@ -11,9 +11,9 @@
#include "shellinsertdlg.h"
-#include <qcombobox.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
+#include <tqcombobox.h>
+#include <tqlayout.h>
+#include <tqpushbutton.h>
#include <kconfig.h>
#include <kbuttonbox.h>
#include <kdebug.h>
@@ -30,11 +30,11 @@
ShellInsertDialog::ShellInsertDialog()
- : QDialog(0, "shell filter dialog", true)
+ : TQDialog(0, "shell filter dialog", true)
{
- QVBoxLayout *layout = new QVBoxLayout(this, 10, 4);
+ TQVBoxLayout *layout = new TQVBoxLayout(this, 10, 4);
- combo = new QComboBox(true, this);
+ combo = new TQComboBox(true, this);
combo->setDuplicatesEnabled(false);
layout->addWidget(combo);
@@ -45,16 +45,16 @@ ShellInsertDialog::ShellInsertDialog()
buttonbox->layout();
layout->addWidget(buttonbox);
- connect( start_button, SIGNAL(clicked()),
- this, SLOT(slotStartClicked()) );
- connect( cancel_button, SIGNAL(clicked()),
- this, SLOT(reject()) );
- connect( combo->lineEdit(), SIGNAL(textChanged( const QString &)), this, SLOT(executeTextChanged( const QString &)));
+ connect( start_button, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(slotStartClicked()) );
+ connect( cancel_button, TQT_SIGNAL(clicked()),
+ this, TQT_SLOT(reject()) );
+ connect( combo->lineEdit(), TQT_SIGNAL(textChanged( const TQString &)), this, TQT_SLOT(executeTextChanged( const TQString &)));
m_proc = 0;
KConfig *config = FilterFactory::instance()->config();
config->setGroup("General");
- QStringList items = config->readListEntry("InsertItems");
+ TQStringList items = config->readListEntry("InsertItems");
combo->insertStringList(items);
executeTextChanged( combo->lineEdit()->text());
@@ -66,8 +66,8 @@ ShellInsertDialog::~ShellInsertDialog()
kdDebug(9029) << "~ShellInsertDialog" << endl;
delete m_proc;
- // QComboBox API is a bit incomplete :-(
- QStringList list;
+ // TQComboBox API is a bit incomplete :-(
+ TQStringList list;
for (int i=0; i < combo->count(); ++i)
list << combo->text(i);
@@ -77,7 +77,7 @@ ShellInsertDialog::~ShellInsertDialog()
}
-void ShellInsertDialog::executeTextChanged( const QString &text)
+void ShellInsertDialog::executeTextChanged( const TQString &text)
{
start_button->setEnabled(!text.isEmpty());
}
@@ -85,29 +85,29 @@ void ShellInsertDialog::executeTextChanged( const QString &text)
int ShellInsertDialog::exec()
{
start_button->setEnabled(true);
- return QDialog::exec();
+ return TQDialog::exec();
}
void ShellInsertDialog::slotStartClicked()
{
start_button->setEnabled(false);
- m_str = QCString();
+ m_str = TQCString();
delete m_proc;
m_proc = new KShellProcess("/bin/sh");
(*m_proc) << combo->currentText();
- connect( m_proc, SIGNAL(receivedStdout(KProcess*, char *, int)),
- this, SLOT(slotReceivedStdout(KProcess*, char *, int)) );
- connect( m_proc, SIGNAL(processExited(KProcess*)),
- this, SLOT(slotProcessExited(KProcess*)) );
+ connect( m_proc, TQT_SIGNAL(receivedStdout(KProcess*, char *, int)),
+ this, TQT_SLOT(slotReceivedStdout(KProcess*, char *, int)) );
+ connect( m_proc, TQT_SIGNAL(processExited(KProcess*)),
+ this, TQT_SLOT(slotProcessExited(KProcess*)) );
m_proc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
}
void ShellInsertDialog::slotReceivedStdout(KProcess *, char *text, int len)
{
- m_str += QCString(text, len+1);
+ m_str += TQCString(text, len+1);
}